#if !defined(BUILTIN_H)
#define BUILTIN_H 1

const char	*builtin_style[] =
{
    /*******************************************************************
    NB: These strings may be no longer than MAXBUF (>= 2048), because
    initialize() must be able to copy them into a fixed buffer,
    line[MAXBUF+2].  They may also not exceed 512 characters in length,
    in order to satisfy a Microsoft C 5.x limit, sigh...

    Tags must consist entirely of exclamation points, letters and
    digits.

    For readability, keep them ordered by grammar level, class, and
    name.
    *******************************************************************/

    /******************************************************************/
    /* Base HTML 1.0 and 2.0 tags */

    "__body__ : BODY",

    "__doctype__ : !DOCTYPE",

    "__font__ : B BIG CODE DFN EM I KBD Q REV SAMP SMALL STRONG TT U VAR",

    "__head__ : HEAD",

    "__html__ : HTML",

    "__line-break__ : BR",

    "__link__ : LINK",

    "__list__ : DIR MENU",
    "__list__ : DL OL UL",

    "__list-header__ : LH",

    "__list-item__ : DD DT LI",

    "__markup-declaration__ : !ATTLIST !ELEMENT !ENTITY !NOTATION !SGML \
			  !SHORTREF !USEMAP",

    "__pair__ : A ABBREV ABSTRACT ADDED ADDRESS ARG AROW ARRAY AU  \
	    BLOCKQUOTE BQ CAPTION CITE CMD DIV1 DIV2 DIV3 DIV4 DIV5 \
	    DIV6 FIG FN FOOTNOTE FORM HIDE LANG MARGIN MATH MESSAGE \
	    NOTE OPTION PERSON QUOTE REMOVED SELECT TABLE TEXTAREA",

    "__paragraph__ : P",

    "__plaintext__ : PLAINTEXT",

    "__section__ : H1 H2 H3 H4 H5 H6",

    "__short__ : ITEM",

    "__standalone__ : CHANGED HR IMG INPUT RENDER STYLES",

    "__standalone-nocheck__ : BASE ISINDEX META",

    "__standalone-nocheck__ : NEXTID",	/* %HTML.Deprecated */

    "__title__ : TITLE",

    "__verbatim__ : LISTING PRE XMP",

    /******************************************************************/
    /* HTML 3.0 additions */

    "__font__ : BT T",

    "__math-pair__ : ABOVE BAR BELOW BOX DDOT DOT HAT ROOT ROW SQRT \
		 TILDE VEC",

    "__math-pair__ : SUB SUP",

    "__math__ : ATOP CHOOSE LEFT OF OVER RIGHT TAB",

    "__pair__ : CREDIT DEL INS",

    "__standalone-nocheck__ : OVERLAY STYLE",

    /******************************************************************/
    /* HTML 3.2 additions */

    "__font__ : STRIKE",

    "__math-pair__ : SUB SUP",

    "__pair__ : APPLET CENTER DIV FONT MAP TD TH TR",

    "__standalone-nocheck__ : AREA BASEFONT PARAM",

    "__verbatim-nocheck__ : SCRIPT STYLE",
    /* NB: STYLE is incompatible between 3.0 and versions 3.2 or later! */

    /******************************************************************/
    /* HTML 4.0 additions */

    "__pair__ : BDO BUTTON COLGROUP FIELDSET FRAMESET IFRAME LABEL \
	   NOFRAMES NOSCRIPT OBJECT SPAN TBODY TFOOT THEAD",

    "__font__ : ACRONYM S",

    "__standalone-nocheck__ : COL FRAME",

    /******************************************************************/
    /* Mosaic additions */

    "__font__ : BLINK",

    "__standalone__ : WBR",

    "__verbatim__ : NOBR",

    /******************************************************************/
    /* Finally, here is information for the DOCTYPE declaration.
       Even though this built-in style includes tags from higher
       grammar levels, for maximum portability, we want the default
       <!DOCTYPE...> declaration produced by html-pretty to be
       suitable for the lowest common denominator.  The complete
       declaration will be this concatenation of strings:

	"<" __doctype__ " " __doctype_name__ " " __doctype_external__ " " __doctype_id__ ">" */

    "__doctype-name__ : HTML",

    "__doctype-external__ : PUBLIC",

    "__doctype-id__ : \"-//IETF//DTD HTML//EN\"",

    /******************************************************************/
     /* The __CannotContain__[] and __ContainedIn__[] values which follow
        were produced automatically from the merged-table.tab file.
	Read "__CannotContain__[X] : Y Z" as X cannot contain Y or Z,
	and "__ContainedIn__[X]: Y Z" as X is contained in Y or Z. */

    "__CannotContain__[A] : A",

    "__CannotContain__[BUTTON] : A BUTTON FIELDSET FORM IFRAME INPUT \
                            ISINDEX LABEL SELECT TEXTAREA",

    "__CannotContain__[DIR] : ADDRESS BLOCKQUOTE BQ CENTER DIR DIV DL \
                            FIELDSET FIG FORM H1 H2 H3 H4 H5 H6 HR \
                            ISINDEX LISTING MENU NOFRAMES NOSCRIPT \
                            NOTE OL P PRE TABLE UL XMP",

    "__CannotContain__[FIG] : FIG IMG",

    "__CannotContain__[FORM] : FORM",

    "__CannotContain__[LABEL] : LABEL",

    "__CannotContain__[MATH] : A ABBREV ACRONYM AU BIG BR CITE CODE DEL \
                            DFN EM I IMG INS KBD LANG MATH PERSON Q S \
                            SAMP SMALL STRONG TAB TT U VAR",

    "__CannotContain__[MENU] : ADDRESS BLOCKQUOTE BQ CENTER DIR DIV DL \
                            FIELDSET FIG FORM H1 H2 H3 H4 H5 H6 HR \
                            ISINDEX LISTING MENU NOFRAMES NOSCRIPT \
                            NOTE OL P PRE TABLE UL XMP",

    "__CannotContain__[NOFRAMES] : #PCDATA A ABBR ADDRESS APPLET B BASEFONT \
                            BDO BIG BLOCKQUOTE BR BUTTON CENTER CITE \
                            CODE DFN DIR DIV DL EM FIELDSET FONT FORM \
                            H1 H2 H3 H4 H5 H6 HR I IFRAME IMG INPUT \
                            ISINDEX KBD LABEL MAP MENU NOFRAMES \
                            NOSCRIPT OBJECT OL P PRE Q S SAMP SCRIPT \
                            SELECT SMALL SPAN STRIKE STRONG SUB SUP \
                            TABLE TEXTAREA TT U UL VAR",

    "__CannotContain__[PRE] : APPLET BASEFONT BIG FONT IMG MATH OBJECT \
                            SMALL SUB SUP TAB",

    "__CannotContain__[SELECT] : INPUT SELECT TEXTAREA",

    "__CannotContain__[TEXTAREA] : INPUT SELECT TEXTAREA",

    "__CannotContain__[TITLE] : LINK META SCRIPT STYLE",

    "__ContainedIn__[#PCDATA] : A ABBR ABBREV ABOVE ACRONYM ADDRESS APPLET \
                            AU B BAR BDO BELOW BIG BLINK BLOCKQUOTE \
                            BODY BOX BQ BT BUTTON CAPTION CENTER CITE \
                            CODE CREDIT DD DDOT DEL DFN DIV DOT DT EM \
                            FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 H6 \
                            HAT I IFRAME INS ITEM KBD LABEL LANG \
                            LEGEND LH LI MATH NOBR NOSCRIPT NOTE \
                            OBJECT OF OPTION P PERSON PRE Q ROOT S \
                            SAMP SMALL SPAN SQRT STRIKE STRONG STYLE \
                            SUB SUP T TD TEXTAREA TEXTFLOW TH TILDE \
                            TITLE TT U VAR VEC",

    "__ContainedIn__[A] : ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ CAPTION \
                            CENTER CITE CODE CREDIT DD DEL DFN DIV DT \
                            EM FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 \
                            H6 I IFRAME INS KBD LABEL LANG LEGEND LH \
                            LI NOBR NOSCRIPT NOTE OBJECT P PERSON PRE \
                            Q S SAMP SMALL SPAN STRIKE STRONG SUB SUP \
                            TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[ABBR] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY BUTTON CAPTION CENTER CITE CODE DD \
                            DEL DFN DIV DT EM FIELDSET FONT FORM H1 H2 \
                            H3 H4 H5 H6 I IFRAME INS KBD LABEL LEGEND \
                            LI NOSCRIPT OBJECT P PRE Q S SAMP SMALL \
                            SPAN STRIKE STRONG SUB SUP TD TH TT U VAR",

    "__ContainedIn__[ABBREV] : A ABBREV ACRONYM ADDRESS AU B BIG \
                            BLOCKQUOTE BODY BQ CAPTION CITE CODE \
                            CREDIT DD DEL DFN DIV DT EM FIG FORM H1 H2 \
                            H3 H4 H5 H6 I INS KBD LANG LH LI NOTE P \
                            PERSON PRE Q S SAMP SMALL STRONG SUB SUP \
                            TD TH TT U VAR",

    "__ContainedIn__[ABOVE] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[ACRONYM] : A ABBREV ACRONYM ADDRESS AU B BIG \
                            BLOCKQUOTE BODY BQ CAPTION CITE CODE \
                            CREDIT DD DEL DFN DIV DT EM FIG FORM H1 H2 \
                            H3 H4 H5 H6 I INS KBD LANG LH LI NOTE P \
                            PERSON PRE Q S SAMP SMALL STRONG SUB SUP \
                            TD TH TT U VAR",

    "__ContainedIn__[ADDRESS] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[ANY] : BASEFONT",

    "__ContainedIn__[APPLET] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY BUTTON CAPTION CENTER CITE CODE DD \
                            DEL DFN DIV DT EM FIELDSET FONT FORM H1 H2 \
                            H3 H4 H5 H6 I IFRAME INS KBD LABEL LEGEND \
                            LI NOSCRIPT OBJECT P PRE Q S SAMP SMALL \
                            SPAN STRIKE STRONG SUB SUP TD TEXTFLOW TH \
                            TT U VAR",

    "__ContainedIn__[AREA] : MAP",

    "__ContainedIn__[ARRAY] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[ATOP] : BOX",

    "__ContainedIn__[AU] : A ABBREV ACRONYM ADDRESS AU B BIG \
                            BLOCKQUOTE BODY BQ CAPTION CITE CODE \
                            CREDIT DD DEL DFN DIV DT EM FIG FORM H1 H2 \
                            H3 H4 H5 H6 I INS KBD LANG LH LI NOTE P \
                            PERSON PRE Q S SAMP SMALL STRONG SUB SUP \
                            TD TH TT U VAR",

    "__ContainedIn__[B] : A ABBR ABBREV ABOVE ACRONYM ADDRESS APPLET \
                            AU B BAR BDO BELOW BIG BLINK BLOCKQUOTE \
                            BODY BOX BQ BT BUTTON CAPTION CENTER CITE \
                            CODE CREDIT DD DDOT DEL DFN DIV DOT DT EM \
                            FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 H6 \
                            HAT I IFRAME INS ITEM KBD LABEL LANG \
                            LEGEND LH LI MATH NOBR NOSCRIPT NOTE \
                            OBJECT OF P PERSON PRE Q ROOT S SAMP SMALL \
                            SPAN SQRT STRIKE STRONG SUB SUP T TD \
                            TEXTFLOW TH TILDE TT U VAR VEC",

    "__ContainedIn__[BAR] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[BASE] : HEAD",

    "__ContainedIn__[BASEFONT] : A ABBR ADDRESS APPLET B BDO BIG BLINK \
                            BLOCKQUOTE BODY BUTTON CAPTION CENTER CITE \
                            CODE DD DEL DFN DIV DT EM FIELDSET FONT \
                            FORM H1 H2 H3 H4 H5 H6 I IFRAME INS KBD \
                            LABEL LEGEND LI NOBR NOSCRIPT OBJECT P PRE \
                            Q S SAMP SMALL SPAN STRIKE STRONG SUB SUP \
                            TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[BDO] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY BUTTON CAPTION CENTER CITE CODE DD \
                            DEL DFN DIV DT EM FIELDSET FONT FORM H1 H2 \
                            H3 H4 H5 H6 I IFRAME INS KBD LABEL LEGEND \
                            LI NOSCRIPT OBJECT P PRE Q S SAMP SMALL \
                            SPAN STRIKE STRONG SUB SUP TD TEXTFLOW TH \
                            TT U VAR",

    "__ContainedIn__[BELOW] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[BIG] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLOCKQUOTE BODY BQ BUTTON CAPTION \
                            CENTER CITE CODE CREDIT DD DEL DFN DIV DT \
                            EM FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 \
                            H6 I IFRAME INS KBD LABEL LANG LEGEND LH \
                            LI NOSCRIPT NOTE OBJECT P PERSON Q S SAMP \
                            SMALL SPAN STRIKE STRONG SUB SUP TD \
                            TEXTFLOW TH TT U VAR",

    "__ContainedIn__[BLINK] : A ADDRESS B BLINK BLOCKQUOTE BODY CENTER \
                            CITE CODE DD DT EM FONT FORM H1 H2 H3 H4 \
                            H5 H6 I KBD LI NOBR P PRE SAMP STRONG TT \
                            VAR",

    "__ContainedIn__[BLOCKQUOTE] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[BODY] : HTML NOFRAMES",

    "__ContainedIn__[BOX] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[BQ] : BLOCKQUOTE BODY BQ DD DIV FIG FORM LI NOTE \
                            TD TH",

    "__ContainedIn__[BR] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FIG FONT FORM H1 H2 H3 \
                            H4 H5 H6 I IFRAME INS KBD LABEL LANG \
                            LEGEND LH LI NOBR NOSCRIPT NOTE OBJECT P \
                            PERSON PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[BT] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[BUTTON] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY CAPTION CENTER CITE CODE DD DEL DFN \
                            DIV DT EM FIELDSET FONT FORM H1 H2 H3 H4 \
                            H5 H6 I IFRAME INS KBD LABEL LEGEND LI \
                            NOSCRIPT OBJECT P PRE Q S SAMP SMALL SPAN \
                            STRIKE STRONG SUB SUP TD TH TT U VAR",

    "__ContainedIn__[CAPTION] : FIELDSET FIG TABLE",

    "__ContainedIn__[CDATA] : LISTING PLAINTEXT SCRIPT STYLE XMP",

    "__ContainedIn__[CENTER] : A ADDRESS APPLET B BLINK BLOCKQUOTE BODY \
                            BUTTON CENTER CITE CODE DD DEL DIV DT EM \
                            FIELDSET FONT FORM H1 H2 H3 H4 H5 H6 I \
                            IFRAME INS KBD LI NOBR NOSCRIPT OBJECT P \
                            SAMP STRONG TD TH TT VAR",

    "__ContainedIn__[CHOOSE] : BOX",

    "__ContainedIn__[CITE] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FIG FONT FORM H1 H2 H3 \
                            H4 H5 H6 I IFRAME INS KBD LABEL LANG \
                            LEGEND LH LI NOBR NOSCRIPT NOTE OBJECT P \
                            PERSON PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[CODE] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FIG FONT FORM H1 H2 H3 \
                            H4 H5 H6 I IFRAME INS KBD LABEL LANG \
                            LEGEND LH LI NOBR NOSCRIPT NOTE OBJECT P \
                            PERSON PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[COL] : COLGROUP TABLE",

    "__ContainedIn__[COLGROUP] : TABLE",

    "__ContainedIn__[CREDIT] : BLOCKQUOTE BQ FIG",

    "__ContainedIn__[DD] : DL",

    "__ContainedIn__[DDOT] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[DEL] : A ABBREV ACRONYM ADDRESS AU B BIG \
                            BLOCKQUOTE BODY BQ CAPTION CITE CODE \
                            CREDIT DD DEL DFN DIV DT EM FIG FORM H1 H2 \
                            H3 H4 H5 H6 I INS KBD LANG LH LI NOTE P \
                            PERSON PRE Q S SAMP SMALL STRONG SUB SUP \
                            TD TH TT U VAR",

    "__ContainedIn__[DFN] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLOCKQUOTE BODY BQ BUTTON CAPTION \
                            CENTER CITE CODE CREDIT DD DEL DFN DIV DT \
                            EM FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 \
                            H6 I IFRAME INS KBD LABEL LANG LEGEND LH \
                            LI NOSCRIPT NOTE OBJECT P PERSON PRE Q S \
                            SAMP SMALL SPAN STRIKE STRONG SUB SUP TD \
                            TEXTFLOW TH TT U VAR",

    "__ContainedIn__[DIR] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[DIV] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[DL] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[DOT] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[DT] : DL",

    "__ContainedIn__[EM] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FIG FONT FORM H1 H2 H3 \
                            H4 H5 H6 I IFRAME INS KBD LABEL LANG \
                            LEGEND LH LI NOBR NOSCRIPT NOTE OBJECT P \
                            PERSON PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[EMPTY] : AREA ATOP BASE BASEFONT BR CHOOSE COL \
                            FRAME HR IMG INPUT ISINDEX LEFT LINK META \
                            NEXTID OVER OVERLAY PARAM RIGHT TAB WBR",

    "__ContainedIn__[FIELDSET] : APPLET BLOCKQUOTE BODY CENTER DD DEL DIV \
                            FIELDSET FORM IFRAME INS LI NOSCRIPT \
                            OBJECT TD TH",

    "__ContainedIn__[FIG] : BLOCKQUOTE BODY BQ DD DIV FORM LI NOTE TD \
                            TH",

    "__ContainedIn__[FONT] : A ABBR ADDRESS APPLET B BDO BIG BLINK \
                            BLOCKQUOTE BODY BUTTON CAPTION CENTER CITE \
                            CODE DD DEL DFN DIV DT EM FIELDSET FONT \
                            FORM H1 H2 H3 H4 H5 H6 I IFRAME INS KBD \
                            LABEL LEGEND LI NOBR NOSCRIPT OBJECT P PRE \
                            Q S SAMP SMALL SPAN STRIKE STRONG SUB SUP \
                            TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[FORM] : APPLET BLOCKQUOTE BODY BQ CENTER DD DEL \
                            DIV FIELDSET FIG IFRAME INS LI NOSCRIPT \
                            NOTE OBJECT TD TH",

    "__ContainedIn__[FRAME] : FRAMESET",

    "__ContainedIn__[FRAMESET] : FRAMESET HTML",

    "__ContainedIn__[H1] : A APPLET BLOCKQUOTE BODY BQ BUTTON CENTER \
                            DD DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[H2] : A APPLET BLOCKQUOTE BODY BQ BUTTON CENTER \
                            DD DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[H3] : A APPLET BLOCKQUOTE BODY BQ BUTTON CENTER \
                            DD DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[H4] : A APPLET BLOCKQUOTE BODY BQ BUTTON CENTER \
                            DD DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[H5] : A APPLET BLOCKQUOTE BODY BQ BUTTON CENTER \
                            DD DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[H6] : A APPLET BLOCKQUOTE BODY BQ BUTTON CENTER \
                            DD DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[HAT] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[HEAD] : HTML",

    "__ContainedIn__[HR] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT PRE TD TH",

    "__ContainedIn__[I] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FIG FONT FORM H1 H2 H3 \
                            H4 H5 H6 I IFRAME INS KBD LABEL LANG \
                            LEGEND LH LI NOBR NOSCRIPT NOTE OBJECT P \
                            PERSON PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[IFRAME] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY CAPTION CENTER CITE CODE DD DEL DFN \
                            DIV DT EM FIELDSET FONT FORM H1 H2 H3 H4 \
                            H5 H6 I IFRAME INS KBD LABEL LEGEND LI \
                            NOSCRIPT OBJECT P PRE Q S SAMP SMALL SPAN \
                            STRIKE STRONG SUB SUP TD TH TT U VAR",

    "__ContainedIn__[IMG] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FONT FORM H1 H2 H3 H4 \
                            H5 H6 I IFRAME INS KBD LABEL LANG LEGEND \
                            LH LI NOBR NOSCRIPT NOTE OBJECT P PERSON Q \
                            S SAMP SMALL SPAN STRIKE STRONG SUB SUP TD \
                            TEXTFLOW TH TT U VAR",

    "__ContainedIn__[INPUT] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY CAPTION CENTER CITE CODE DD DEL DFN \
                            DIV DT EM FIELDSET FONT FORM H1 H2 H3 H4 \
                            H5 H6 I IFRAME INS KBD LABEL LEGEND LI \
                            NOSCRIPT OBJECT P PRE Q S SAMP SMALL SPAN \
                            STRIKE STRONG SUB SUP TD TEXTFLOW TH TT U \
                            VAR",

    "__ContainedIn__[INS] : A ABBREV ACRONYM ADDRESS AU B BIG \
                            BLOCKQUOTE BODY BQ CAPTION CITE CODE \
                            CREDIT DD DEL DFN DIV DT EM FIG FORM H1 H2 \
                            H3 H4 H5 H6 I INS KBD LANG LH LI NOTE P \
                            PERSON PRE Q S SAMP SMALL STRONG SUB SUP \
                            TD TH TT U VAR",

    "__ContainedIn__[ISINDEX] : APPLET BLOCKQUOTE BODY BQ CENTER DD DEL \
                            DIV FIELDSET FIG FORM HEAD IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[ITEM] : ROW",

    "__ContainedIn__[KBD] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FIG FONT FORM H1 H2 H3 \
                            H4 H5 H6 I IFRAME INS KBD LABEL LANG \
                            LEGEND LH LI NOBR NOSCRIPT NOTE OBJECT P \
                            PERSON PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[LABEL] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY CAPTION CENTER CITE CODE DD DEL DFN \
                            DIV DT EM FIELDSET FONT FORM H1 H2 H3 H4 \
                            H5 H6 I IFRAME INS KBD LEGEND LI NOSCRIPT \
                            OBJECT P PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[LANG] : A ABBREV ACRONYM ADDRESS AU B BIG \
                            BLOCKQUOTE BODY BQ CAPTION CITE CODE \
                            CREDIT DD DEL DFN DIV DT EM FIG FORM H1 H2 \
                            H3 H4 H5 H6 I INS KBD LANG LH LI NOTE P \
                            PERSON PRE Q S SAMP SMALL STRONG SUB SUP \
                            TD TH TT U VAR",

    "__ContainedIn__[LEFT] : BOX",

    "__ContainedIn__[LEGEND] : FIELDSET",

    "__ContainedIn__[LH] : DL OL UL",

    "__ContainedIn__[LI] : DIR MENU OL UL",

    "__ContainedIn__[LINK] : HEAD",

    "__ContainedIn__[LISTING] : BLOCKQUOTE BODY BQ CENTER DD DIV FIELDSET \
                            FIG FORM LI NOTE OBJECT TD TH",

    "__ContainedIn__[MAP] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY BUTTON CAPTION CENTER CITE CODE DD \
                            DEL DFN DIV DT EM FIELDSET FONT FORM H1 H2 \
                            H3 H4 H5 H6 I IFRAME INS KBD LABEL LEGEND \
                            LI NOSCRIPT OBJECT P PRE Q S SAMP SMALL \
                            SPAN STRIKE STRONG SUB SUP TD TEXTFLOW TH \
                            TT U VAR",

    "__ContainedIn__[MATH] : A ABBREV ACRONYM ADDRESS AU B BIG \
                            BLOCKQUOTE BODY BQ CAPTION CITE CODE \
                            CREDIT DD DEL DFN DIV DT EM FIG FORM H1 H2 \
                            H3 H4 H5 H6 I INS KBD LANG LH LI NOTE P \
                            PERSON Q S SAMP SMALL STRONG SUB SUP TD TH \
                            TT U VAR",

    "__ContainedIn__[MENU] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[META] : HEAD",

    "__ContainedIn__[NEXTID] : HEAD",

    "__ContainedIn__[NOBR] : A ADDRESS B BLINK BLOCKQUOTE BODY CENTER \
                            CITE CODE DD DT EM FONT FORM H1 H2 H3 H4 \
                            H5 H6 I KBD LI NOBR P SAMP STRONG TT VAR",

    "__ContainedIn__[NOFRAMES] : APPLET BLOCKQUOTE BODY BUTTON CENTER DD \
                            DEL DIV FIELDSET FORM FRAMESET IFRAME INS \
                            LI NOSCRIPT OBJECT TD TH",

    "__ContainedIn__[NOSCRIPT] : APPLET BLOCKQUOTE BODY BUTTON CENTER DD \
                            DEL DIV FIELDSET FORM IFRAME INS LI \
                            NOSCRIPT OBJECT TD TH",

    "__ContainedIn__[NOTE] : BLOCKQUOTE BODY BQ DD DIV FIG FORM LI NOTE \
                            TD TH",

    "__ContainedIn__[OBJECT] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY BUTTON CAPTION CENTER CITE CODE DD \
                            DEL DFN DIV DT EM FIELDSET FONT FORM H1 H2 \
                            H3 H4 H5 H6 I IFRAME INS KBD LABEL LEGEND \
                            LI NOSCRIPT OBJECT P PRE Q S SAMP SMALL \
                            SPAN STRIKE STRONG SUB SUP TD TEXTFLOW TH \
                            TT U VAR",

    "__ContainedIn__[OF] : ROOT",

    "__ContainedIn__[OL] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[OPTGROUP] : OPTGROUP SELECT",

    "__ContainedIn__[OPTION] : OPTGROUP SELECT",

    "__ContainedIn__[OVER] : BOX",

    "__ContainedIn__[OVERLAY] : FIG",

    "__ContainedIn__[P] : ADDRESS APPLET BLOCKQUOTE BODY BQ BUTTON \
                            CENTER DD DEL DIV FIELDSET FIG FORM IFRAME \
                            INS LI NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[PARAM] : APPLET OBJECT",

    "__ContainedIn__[PERSON] : A ABBREV ACRONYM ADDRESS AU B BIG \
                            BLOCKQUOTE BODY BQ CAPTION CITE CODE \
                            CREDIT DD DEL DFN DIV DT EM FIG FORM H1 H2 \
                            H3 H4 H5 H6 I INS KBD LANG LH LI NOTE P \
                            PERSON PRE Q S SAMP SMALL STRONG SUB SUP \
                            TD TH TT U VAR",

    "__ContainedIn__[PLAINTEXT] : HTML",

    "__ContainedIn__[PRE] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[Q] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLOCKQUOTE BODY BQ BUTTON CAPTION \
                            CENTER CITE CODE CREDIT DD DEL DFN DIV DT \
                            EM FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 \
                            H6 I IFRAME INS KBD LABEL LANG LEGEND LH \
                            LI NOSCRIPT NOTE OBJECT P PERSON PRE Q S \
                            SAMP SMALL SPAN STRIKE STRONG SUB SUP TD \
                            TEXTFLOW TH TT U VAR",

    "__ContainedIn__[RIGHT] : BOX",

    "__ContainedIn__[ROOT] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[ROW] : ARRAY",

    "__ContainedIn__[S] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLOCKQUOTE BODY BQ BUTTON CAPTION \
                            CENTER CITE CODE CREDIT DD DEL DFN DIV DT \
                            EM FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 \
                            H6 I IFRAME INS KBD LABEL LANG LEGEND LH \
                            LI NOSCRIPT NOTE OBJECT P PERSON PRE Q S \
                            SAMP SMALL SPAN STRIKE STRONG SUB SUP TD \
                            TEXTFLOW TH TT U VAR",

    "__ContainedIn__[SAMP] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FIG FONT FORM H1 H2 H3 \
                            H4 H5 H6 I IFRAME INS KBD LABEL LANG \
                            LEGEND LH LI NOBR NOSCRIPT NOTE OBJECT P \
                            PERSON PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[SCRIPT] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY BUTTON CAPTION CENTER CITE CODE DD \
                            DEL DFN DIV DT EM FIELDSET FONT FORM H1 H2 \
                            H3 H4 H5 H6 HEAD I IFRAME INS KBD LABEL \
                            LEGEND LI NOSCRIPT OBJECT P PRE Q S SAMP \
                            SMALL SPAN STRIKE STRONG SUB SUP TD \
                            TEXTFLOW TH TT U VAR",

    "__ContainedIn__[SELECT] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY CAPTION CENTER CITE CODE DD DEL DFN \
                            DIV DT EM FIELDSET FONT FORM H1 H2 H3 H4 \
                            H5 H6 I IFRAME INS KBD LABEL LEGEND LI \
                            NOSCRIPT OBJECT P PRE Q S SAMP SMALL SPAN \
                            STRIKE STRONG SUB SUP TD TEXTFLOW TH TT U \
                            VAR",

    "__ContainedIn__[SMALL] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLOCKQUOTE BODY BQ BUTTON CAPTION \
                            CENTER CITE CODE CREDIT DD DEL DFN DIV DT \
                            EM FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 \
                            H6 I IFRAME INS KBD LABEL LANG LEGEND LH \
                            LI NOSCRIPT NOTE OBJECT P PERSON Q S SAMP \
                            SMALL SPAN STRIKE STRONG SUB SUP TD \
                            TEXTFLOW TH TT U VAR",

    "__ContainedIn__[SPAN] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY BUTTON CAPTION CENTER CITE CODE DD \
                            DEL DFN DIV DT EM FIELDSET FONT FORM H1 H2 \
                            H3 H4 H5 H6 I IFRAME INS KBD LABEL LEGEND \
                            LI NOSCRIPT OBJECT P PRE Q S SAMP SMALL \
                            SPAN STRIKE STRONG SUB SUP TD TEXTFLOW TH \
                            TT U VAR",

    "__ContainedIn__[SQRT] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[STRIKE] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY BUTTON CAPTION CENTER CITE CODE DD \
                            DEL DFN DIV DT EM FIELDSET FONT FORM H1 H2 \
                            H3 H4 H5 H6 I IFRAME INS KBD LABEL LEGEND \
                            LI NOSCRIPT OBJECT P PRE Q S SAMP SMALL \
                            SPAN STRIKE STRONG SUB SUP TD TH TT U VAR",

    "__ContainedIn__[STRONG] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FIG FONT FORM H1 H2 H3 \
                            H4 H5 H6 I IFRAME INS KBD LABEL LANG \
                            LEGEND LH LI NOBR NOSCRIPT NOTE OBJECT P \
                            PERSON PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[STYLE] : A ADDRESS B BDO BIG BLOCKQUOTE BODY \
                            CAPTION CENTER CITE CODE DD DFN DIV DT EM \
                            FIELDSET FONT FORM H1 H2 H3 H4 H5 H6 HEAD \
                            I KBD LABEL LI OBJECT P PRE Q S SAMP SMALL \
                            SPAN STRONG SUB SUP TD TEXTFLOW TH TT U \
                            VAR",

    "__ContainedIn__[SUB] : A ABBR ABBREV ABOVE ACRONYM ADDRESS APPLET \
                            AU B BAR BDO BELOW BIG BLOCKQUOTE BODY BOX \
                            BQ BT BUTTON CAPTION CENTER CITE CODE \
                            CREDIT DD DDOT DEL DFN DIV DOT DT EM \
                            FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 H6 \
                            HAT I IFRAME INS ITEM KBD LABEL LANG \
                            LEGEND LH LI MATH NOSCRIPT NOTE OBJECT OF \
                            P PERSON Q ROOT S SAMP SMALL SPAN SQRT \
                            STRIKE STRONG SUB SUP T TD TEXTFLOW TH \
                            TILDE TT U VAR VEC",

    "__ContainedIn__[SUP] : A ABBR ABBREV ABOVE ACRONYM ADDRESS APPLET \
                            AU B BAR BDO BELOW BIG BLOCKQUOTE BODY BOX \
                            BQ BT BUTTON CAPTION CENTER CITE CODE \
                            CREDIT DD DDOT DEL DFN DIV DOT DT EM \
                            FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 H6 \
                            HAT I IFRAME INS ITEM KBD LABEL LANG \
                            LEGEND LH LI MATH NOSCRIPT NOTE OBJECT OF \
                            P PERSON Q ROOT S SAMP SMALL SPAN SQRT \
                            STRIKE STRONG SUB SUP T TD TEXTFLOW TH \
                            TILDE TT U VAR VEC",

    "__ContainedIn__[T] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[TAB] : A ABBREV ACRONYM ADDRESS AU B BIG \
                            BLOCKQUOTE BODY BQ CAPTION CITE CODE \
                            CREDIT DD DEL DFN DIV DT EM FIG FORM H1 H2 \
                            H3 H4 H5 H6 I INS KBD LANG LH LI NOTE P \
                            PERSON Q S SAMP SMALL STRONG SUB SUP TD TH \
                            TT U VAR",

    "__ContainedIn__[TABLE] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[TBODY] : TABLE",

    "__ContainedIn__[TD] : TR",

    "__ContainedIn__[TEXTAREA] : A ABBR ADDRESS APPLET B BDO BIG BLOCKQUOTE \
                            BODY CAPTION CENTER CITE CODE DD DEL DFN \
                            DIV DT EM FIELDSET FONT FORM H1 H2 H3 H4 \
                            H5 H6 I IFRAME INS KBD LABEL LEGEND LI \
                            NOSCRIPT OBJECT P PRE Q S SAMP SMALL SPAN \
                            STRIKE STRONG SUB SUP TD TEXTFLOW TH TT U \
                            VAR",

    "__ContainedIn__[TEXTFLOW] : APPLET",

    "__ContainedIn__[TFOOT] : TABLE",

    "__ContainedIn__[TH] : TR",

    "__ContainedIn__[THEAD] : TABLE",

    "__ContainedIn__[TILDE] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[TITLE] : HEAD",

    "__ContainedIn__[TR] : TABLE TBODY TFOOT THEAD",

    "__ContainedIn__[TT] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FIG FONT FORM H1 H2 H3 \
                            H4 H5 H6 I IFRAME INS KBD LABEL LANG \
                            LEGEND LH LI NOBR NOSCRIPT NOTE OBJECT P \
                            PERSON PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[U] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLOCKQUOTE BODY BQ BUTTON CAPTION \
                            CENTER CITE CODE CREDIT DD DEL DFN DIV DT \
                            EM FIELDSET FIG FONT FORM H1 H2 H3 H4 H5 \
                            H6 I IFRAME INS KBD LABEL LANG LEGEND LH \
                            LI NOSCRIPT NOTE OBJECT P PERSON PRE Q S \
                            SAMP SMALL SPAN STRIKE STRONG SUB SUP TD \
                            TEXTFLOW TH TT U VAR",

    "__ContainedIn__[UL] : APPLET BLOCKQUOTE BODY BQ BUTTON CENTER DD \
                            DEL DIV FIELDSET FIG FORM IFRAME INS LI \
                            NOSCRIPT NOTE OBJECT TD TH",

    "__ContainedIn__[VAR] : A ABBR ABBREV ACRONYM ADDRESS APPLET AU B \
                            BDO BIG BLINK BLOCKQUOTE BODY BQ BUTTON \
                            CAPTION CENTER CITE CODE CREDIT DD DEL DFN \
                            DIV DT EM FIELDSET FIG FONT FORM H1 H2 H3 \
                            H4 H5 H6 I IFRAME INS KBD LABEL LANG \
                            LEGEND LH LI NOBR NOSCRIPT NOTE OBJECT P \
                            PERSON PRE Q S SAMP SMALL SPAN STRIKE \
                            STRONG SUB SUP TD TEXTFLOW TH TT U VAR",

    "__ContainedIn__[VEC] : ABOVE BAR BELOW BOX BT DDOT DOT HAT ITEM \
                            MATH OF ROOT SQRT T TILDE VEC",

    "__ContainedIn__[WBR] : A ADDRESS B BLINK BLOCKQUOTE BODY CENTER \
                            CITE CODE DD DT EM FONT FORM H1 H2 H3 H4 \
                            H5 H6 I KBD LI NOBR P SAMP STRONG TT VAR",

    "__ContainedIn__[XMP] : BLOCKQUOTE BODY BQ CENTER DD DIV FIELDSET \
                            FIG FORM LI NOTE OBJECT TD TH",

    /* data terminator */
    (const char*)NULL
};
#endif /* !defined(BUILTIN_H) */
